pub struct NpodConfig {
pub max_cycles: usize,
pub error_optim: ErrorOptimConfig,
pub progress: bool,
}Expand description
Configuration options for the Non-Parametric Optimal Design (NPOD) algorithm.
Fields
max_cycles: usizeMaximum number of cycles to run the algorithm for.
error_optim: ErrorOptimConfigConfiguration for the error-model factor (gamma/lambda) optimization.
progress: boolWhether to print progress information during the first cycle.
Implementations
Sourceimpl NpodConfig
impl NpodConfig
pub fn new() -> Self
pub fn max_cycles(self, cycles: usize) -> Self
pub fn error_optim(self, config: ErrorOptimConfig) -> Self
pub fn progress(self, progress: bool) -> Self